summaryrefslogtreecommitdiffstats
path: root/util/include
diff options
context:
space:
mode:
Diffstat (limited to 'util/include')
-rw-r--r--util/include/axutil_date_time.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/util/include/axutil_date_time.h b/util/include/axutil_date_time.h
index eeac9e6..4276386 100644
--- a/util/include/axutil_date_time.h
+++ b/util/include/axutil_date_time.h
@@ -216,13 +216,13 @@ extern "C"
const axutil_env_t * env);
/**
* retrieve the date of the date time
* @param date_time represet the type object
* @param env pointer to environment struct. MUST NOT be NULL
* @return date as an integer
*/
AXIS2_EXTERN int AXIS2_CALL
- axutil_date_time_get_date(
+ axutil_date_time_get_day(
axutil_date_time_t * date_time,
const axutil_env_t * env);
@@ -216,13 +216,13 @@ extern "C"
const axutil_env_t * env);
/**
- * retrieve the date of the date time
+ * retrieve the day of the date time
* @param date_time represet the type object
* @param env pointer to environment struct. MUST NOT be NULL
@@ -216,13 +216,13 @@ extern "C"
* @param date_time represet the type object
* @param env pointer to environment struct. MUST NOT be NULL
- * @return date as an integer
+ * @return day as an integer
*/
AXIS2_EXTERN int AXIS2_CALL